import {Component, OnInit} from '@angular/core';
import {NzMessageService} from 'ng-zorro-antd';
import {ModalHelper} from '@delon/theme';
import {HttpClient} from '@angular/common/http';
import {UserInstallerEditComponent} from './edit/edit.component';
import {environment} from 'environments/environment';
import {DateService} from '@business/services/util/date.service';
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import { ResultBean } from '@business/entity/grid';

@Component({
  selector: 'app-installer',
  templateUrl: './installer.component.html',
  styles: []
})
export class InstallerComponent implements OnInit {
  isDeleteOptions = [
    {value: '1', label: '是'},
    {value: '0', label: '否'}
  ];
  q: any = {
    pi: 1,
    ps: 10,
    isDelete: this.isDeleteOptions[1].value,
    sorter: '',
    u_name: '',
    u_mobile: ''
  };
  data: any[] = [];
  total: 0;

  selectedRows: any[] = [];
  curRows: any[] = [];
  allChecked = false;
  indeterminate = false;
  sortMap: any = {};
  loading = true;

  constructor(
    public http: HttpClient,
    public dateSrv: DateService,
    public msgSrv: NzMessageService,
    private modalHelper: ModalHelper,
    private fb: FormBuilder
  ) {}

  ngOnInit() {
    this.load();
    // 重置密码表单初始化
    this.resetPwdForm = this.fb.group({
      name    : [ null, [ Validators.email ] ],
      password         : [ null, [ Validators.required ] ],
      checkPassword    : [ null, [ Validators.required, this.confirmationValidator ] ]
      });
  }

  load(reload: boolean = false) {
    if (reload) {
      this.q.pi = 1;
    }
    this.http.get(environment.SERVER_BASH_URL + '/operateUser/list', {params: this.q}).subscribe((res: any) => {
      this.data = res.data.data;
      this.total = res.data.total;
      this.dataChange(this.data);
      this.loading = false;
    });
  }

  edit(user) {
    this.modalHelper.static(UserInstallerEditComponent, {user}).subscribe(() => {
      this.load(true);
      this.msgSrv.success('安装用户修改成功！');
    });
  }

  add() {
    const user = {};
    this.modalHelper.static(UserInstallerEditComponent, {user}).subscribe(() => {
      this.load(true);
      this.msgSrv.success('安装用户保存成功！');
    });
  }

  delete(user) {
    this.http.post(environment.SERVER_BASH_URL + '/operateUser/operateUser/id', user).subscribe((res: any) => {
      this.msgSrv.success('安装用户删除成功！');
      this.load(true);
    });
  }

  remove() {
    const ids = [];
    this.selectedRows.forEach(i => {
      ids.push(i.id);
    });
    this.http.post(environment.SERVER_BASH_URL + '/operateUser/operateUsers/ids', ids).subscribe((res: any) => {
      this.msgSrv.success('安装用户删除成功！');
      this.load(true);
    });
  }

  checkAll(value: boolean) {
    this.curRows.forEach(i => {
      if (i.isDelete === '1') {
        i.checked = false;
      } else {
        i.checked = value;
      }
    });
    this.refreshStatus();
  }

  dataChange(res: any) {
    this.curRows = res;
    this.refreshStatus();
  }

  refreshStatus() {
    const allChecked = this.curRows.every(value => value.checked);
    const allUnChecked = this.curRows.every(value => !value.checked);
    this.allChecked = allChecked;
    this.indeterminate = (!allChecked) && (!allUnChecked);
    this.selectedRows = this.data.filter(value => value.checked);
  }

  sort(field: string, value: any) {
    this.sortMap = {};
    this.sortMap[field] = value;
    this.q.sorter = value ? `${field} ${value}` : '';
    this.load(true);
  }

  reset(ls: any[]) {
    for (const item of ls) item.value = false;
    this.load(true);
  }

  format_date(date) {
    if (date) {
      return this.dateSrv.date_format(date, 'YYYY-MM-DD');
    }
  }
  public resetPwdWindowIsVisible = false;
  public isResetPwdLoading = false;
  public resetPwdForm: FormGroup;
  public resetPwdCancel() {
    this.resetPwdWindowIsVisible = false;
}
public resetPwdOk() {
  for (const i in this.resetPwdForm.controls) {
    this.resetPwdForm.controls[ i ].markAsDirty();
  }
  if (this.resetPwdForm.valid) {
     this.isResetPwdLoading = true;
     const data = this.resetPwdForm.value;
     data['name'] = null;
     this.http.post(environment.SERVER_BASH_URL + '/operateUser/operateUser', data).subscribe((res: ResultBean<any>) => {
       if ( res.code === 1 && res.data === 1 ) {
        this.isResetPwdLoading = false;
        this.resetPwdWindowIsVisible = false;
        this.msgSrv.success('密码修改成功！');
       }
    });
  }
}
  /**
   *  显示修改密码弹窗
   * @param account 
   */
  public showResetPwdWindow(install) {
    this.resetPwdWindowIsVisible = true;
    this.resetPwdForm = this.fb.group({
      id               : [ install.id ],
      name      : [ install.name],
      password         : [ null, [ Validators.required ] ],
      checkPassword    : [ null, [ Validators.required, this.confirmationValidator ] ]
    });
  }
  confirmationValidator = (control: FormControl): { [s: string]: boolean } => {
    if (!control.value) {
      return { required: true };
    } else if (control.value !== this.resetPwdForm.controls[ 'password' ].value) {
      return { confirm: true, error: true };
    }
  }
  /**
   * 根据 formControl名字 获取 对象，页面调用
   * @param name y
   */
  public getFormControl(name) {
    return this.resetPwdForm.controls[ name ];
  }
  updateConfirmValidator() {
    /** wait for refresh value */
    setTimeout(_ => {
      this.resetPwdForm.controls[ 'checkPassword' ].updateValueAndValidity();
    });
  }
}
